function TT = Tlump(tau,tf)
% Tlump  Plot T(t) for lumped mass (small Bi) with convective BC
%
% Synopsis:  T = TuniLump(tau,tf)
%
% Input:    tau = time constant, same units as tf
%           tf  = final time, same units as tau
%
% Output:   T = vector of dimensionless temperatures (theta) at 100
%               evenly spaced times between 0 and tf

if nargin<1, tau=1;     end
if nargin<2, tf=3*tau;  end

t = linspace(0,tf);
T = exp(-t/tau);
plot(t/tau,T);
xlabel('t/\tau');  ylabel('\theta');
title('Transient response of a lumped mass');

if nargout==1, TT=T;  end

end